@@ -6,7 +6,7 @@ Provides shared display methods, configurations, and utilities.
 
 from .configs import DocumentAdminConfigs
 from .display_helpers import DocumentDisplayHelpers
-from .statistics import DocumentStatistics, ChunkStatistics, CategoryStatistics
+from .statistics import CategoryStatistics, ChunkStatistics, DocumentStatistics
 
 __all__ = [
     'DocumentAdminConfigs',
