@@ -4,28 +4,24 @@ Newsletter admin interfaces using Django-CFG admin system.
 Refactored admin interfaces with Material Icons and optimized queries.
 """
 
-from .newsletter_admin import (
-    EmailLogAdmin, 
-    NewsletterAdmin, 
-    NewsletterSubscriptionAdmin, 
-    NewsletterCampaignAdmin
-)
 from .filters import (
-    UserEmailFilter, 
-    UserNameFilter, 
-    HasUserFilter, 
-    EmailOpenedFilter, 
-    EmailClickedFilter
+    EmailClickedFilter,
+    EmailOpenedFilter,
+    HasUserFilter,
+    UserEmailFilter,
+    UserNameFilter,
 )
-from .resources import (
-    NewsletterResource, 
-    NewsletterSubscriptionResource, 
-    EmailLogResource
+from .newsletter_admin import (
+    EmailLogAdmin,
+    NewsletterAdmin,
+    NewsletterCampaignAdmin,
+    NewsletterSubscriptionAdmin,
 )
+from .resources import EmailLogResource, NewsletterResource, NewsletterSubscriptionResource
 
 __all__ = [
     'EmailLogAdmin',
-    'NewsletterAdmin', 
+    'NewsletterAdmin',
     'NewsletterSubscriptionAdmin',
     'NewsletterCampaignAdmin',
     'UserEmailFilter',
