@@ -6,15 +6,16 @@ Modern, clean admin interfaces with Material Icons and no HTML duplication.
 
 from django.contrib import admin
 
-# Import all admin classes
-from .balance_admin import UserBalanceAdmin, TransactionAdmin
-from .payments_admin import UniversalPaymentAdmin
 from .api_keys_admin import APIKeyAdmin
+
+# Import all admin classes
+from .balance_admin import TransactionAdmin, UserBalanceAdmin
 from .currencies_admin import CurrencyAdmin  # Use working version
+from .endpoint_groups_admin import EndpointGroupAdmin
+from .networks_admin import NetworkAdmin, ProviderCurrencyAdmin
+from .payments_admin import UniversalPaymentAdmin
 from .subscriptions_admin import SubscriptionAdmin
 from .tariffs_admin import TariffAdmin, TariffEndpointGroupAdmin
-from .networks_admin import NetworkAdmin, ProviderCurrencyAdmin
-from .endpoint_groups_admin import EndpointGroupAdmin
 
 # All models are registered in their respective admin files using @admin.register
 # This provides:
