@@ -6,26 +6,25 @@ All models follow the data typing requirements: Django ORM for database layer.
 """
 
 # Base models
+# API Keys
+from .api_keys import APIKey
+
+# Balance models
+from .balance import Transaction, UserBalance
 from .base import UUIDTimestampedModel
 
 # Currency models
 from .currencies import Currency, Network, ProviderCurrency
 
-# Payment models  
+# Payment models
 from .payments import UniversalPayment
 
-# Balance models
-from .balance import UserBalance, Transaction
-
 # Subscription models
-from .subscriptions import Subscription, EndpointGroup
+from .subscriptions import EndpointGroup, Subscription
 
 # Tariff models
 from .tariffs import Tariff, TariffEndpointGroup
 
-# API Keys
-from .api_keys import APIKey
-
 # Export TextChoices for external use
 PaymentStatus = UniversalPayment.PaymentStatus
 PaymentProvider = UniversalPayment.PaymentProvider
@@ -37,22 +36,22 @@ SubscriptionTier = Subscription.SubscriptionTier
 __all__ = [
     # Base
     'UUIDTimestampedModel',
-    
+
     # Currencies
     'Currency',
     'Network',
     'ProviderCurrency',
-    
+
     # Core Models
     'UniversalPayment',
     'UserBalance',
-    'Transaction', 
+    'Transaction',
     'Subscription',
     'EndpointGroup',
     'Tariff',
     'TariffEndpointGroup',
     'APIKey',
-    
+
     # TextChoices
     'PaymentStatus',
     'PaymentProvider',
