@@ -10,6 +10,7 @@ All business logic is in managers to avoid duplication.
 """
 
 from django.apps import apps
+
 from django_cfg.modules.django_logging import get_logger
 
 logger = get_logger("payment_signals")
@@ -23,13 +24,10 @@ def register_signals():
     """
     try:
         # Import signal modules to register them
-        from . import payment_signals
-        from . import balance_signals
-        from . import subscription_signals
-        from . import api_key_signals
-        
+        from . import api_key_signals, balance_signals, payment_signals, subscription_signals
+
         logger.info("Payment signals registered successfully")
-        
+
     except ImportError as e:
         logger.error(f"Failed to register payment signals: {e}")
 
