@@ -4,25 +4,26 @@ Currency ViewSets for the Universal Payment System v2.0.
 DRF ViewSets for currency management with service integration.
 """
 
-from rest_framework import viewsets, permissions, status, generics
+from django.utils import timezone
+from drf_spectacular.types import OpenApiTypes
+from drf_spectacular.utils import OpenApiParameter, extend_schema
+from rest_framework import generics, permissions, status
 from rest_framework.decorators import action
 from rest_framework.response import Response
-from django_filters.rest_framework import DjangoFilterBackend
-from django.utils import timezone
 
-from .base import ReadOnlyPaymentViewSet
+from django_cfg.modules.django_logging import get_logger
+
 from ...models import Currency, Network, ProviderCurrency
-from ...services import get_currency_service
 from ..serializers.currencies import (
-    CurrencySerializer,
+    CurrencyConversionSerializer,
     CurrencyListSerializer,
+    CurrencyRatesSerializer,
+    CurrencySerializer,
     NetworkSerializer,
     ProviderCurrencySerializer,
-    CurrencyConversionSerializer,
-    CurrencyRatesSerializer,
     SupportedCurrenciesSerializer,
 )
-from django_cfg.modules.django_logging import get_logger
+from .base import ReadOnlyPaymentViewSet
 
 logger = get_logger("currency_viewsets")
 
@@ -33,22 +34,22 @@ class CurrencyViewSet(ReadOnlyPaymentViewSet):
     
     Read-only access to currency information with conversion capabilities.
     """
-    
+
     # Allow POST for conversion action
     http_method_names = ['get', 'head', 'options', 'post']
-    
+
     queryset = Currency.objects.filter(is_active=True)
     serializer_class = CurrencySerializer
     permission_classes = [permissions.IsAuthenticated]
     filterset_fields = ['currency_type', 'is_active']
     search_fields = ['code', 'name', 'symbol']
     ordering_fields = ['code', 'name', 'created_at']
-    
+
     serializer_classes = {
         'list': CurrencyListSerializer,
         'retrieve': CurrencySerializer,
     }
-    
+
     @action(detail=False, methods=['get'])
     def crypto(self, request):
         """
@@ -58,14 +59,14 @@ class CurrencyViewSet(ReadOnlyPaymentViewSet):
         """
         cryptos = self.get_queryset().filter(currency_type='crypto')
         serializer = CurrencyListSerializer(cryptos, many=True)
-        
+
         return Response({
             'currencies': serializer.data,
             'count': len(serializer.data),
             'type': 'crypto',
             'generated_at': timezone.now().isoformat()
         })
-    
+
     @action(detail=False, methods=['get'])
     def fiat(self, request):
         """
@@ -75,14 +76,14 @@ class CurrencyViewSet(ReadOnlyPaymentViewSet):
         """
         fiats = self.get_queryset().filter(currency_type='fiat')
         serializer = CurrencyListSerializer(fiats, many=True)
-        
+
         return Response({
             'currencies': serializer.data,
             'count': len(serializer.data),
             'type': 'fiat',
             'generated_at': timezone.now().isoformat()
         })
-    
+
     @action(detail=False, methods=['get'])
     def stable(self, request):
         """
@@ -95,14 +96,14 @@ class CurrencyViewSet(ReadOnlyPaymentViewSet):
             code__in=['USDT', 'USDC', 'DAI', 'BUSD', 'TUSD']
         )
         serializer = CurrencyListSerializer(stables, many=True)
-        
+
         return Response({
             'currencies': serializer.data,
             'count': len(serializer.data),
             'type': 'stable',
             'generated_at': timezone.now().isoformat()
         })
-    
+
     @action(detail=True, methods=['get'])
     def networks(self, request, pk=None):
         """
@@ -113,14 +114,14 @@ class CurrencyViewSet(ReadOnlyPaymentViewSet):
         currency = self.get_object()
         networks = Network.objects.filter(currency=currency, is_active=True)
         serializer = NetworkSerializer(networks, many=True)
-        
+
         return Response({
             'currency': CurrencyListSerializer(currency).data,
             'networks': serializer.data,
             'count': len(serializer.data),
             'generated_at': timezone.now().isoformat()
         })
-    
+
     @action(detail=True, methods=['get'])
     def providers(self, request, pk=None):
         """
@@ -134,14 +135,14 @@ class CurrencyViewSet(ReadOnlyPaymentViewSet):
             is_enabled=True
         )
         serializer = ProviderCurrencySerializer(provider_currencies, many=True)
-        
+
         return Response({
             'currency': CurrencyListSerializer(currency).data,
             'providers': serializer.data,
             'count': len(serializer.data),
             'generated_at': timezone.now().isoformat()
         })
-    
+
     @action(detail=False, methods=['post'])
     def convert(self, request):
         """
@@ -150,41 +151,82 @@ class CurrencyViewSet(ReadOnlyPaymentViewSet):
         POST /api/currencies/convert/
         """
         serializer = CurrencyConversionSerializer(data=request.data)
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-    
+
+    @extend_schema(
+        parameters=[
+            OpenApiParameter(
+                name='base_currency',
+                type=OpenApiTypes.STR,
+                location=OpenApiParameter.QUERY,
+                description='Base currency code (e.g., USD)',
+                required=True,
+            ),
+            OpenApiParameter(
+                name='currencies',
+                type=OpenApiTypes.STR,
+                location=OpenApiParameter.QUERY,
+                description='Comma-separated list of target currency codes (e.g., BTC,ETH,USDT)',
+                required=True,
+            ),
+        ],
+        summary='Get exchange rates',
+        description='Get current exchange rates for specified currencies',
+    )
     @action(detail=False, methods=['get'])
     def rates(self, request):
         """
         Get current exchange rates.
-        
+
         GET /api/currencies/rates/?base_currency=USD&currencies=BTC,ETH
         """
         serializer = CurrencyRatesSerializer(data=request.query_params)
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-    
+
+    @extend_schema(
+        parameters=[
+            OpenApiParameter(
+                name='provider',
+                type=OpenApiTypes.STR,
+                location=OpenApiParameter.QUERY,
+                description='Payment provider name (e.g., nowpayments)',
+                required=False,
+            ),
+            OpenApiParameter(
+                name='currency_type',
+                type=OpenApiTypes.STR,
+                location=OpenApiParameter.QUERY,
+                description='Currency type filter: crypto, fiat, or stablecoin',
+                required=False,
+                enum=['crypto', 'fiat', 'stablecoin'],
+            ),
+        ],
+        summary='Get supported currencies',
+        description='Get list of supported currencies from payment providers',
+    )
     @action(detail=False, methods=['get'])
     def supported(self, request):
         """
         Get supported currencies from providers.
-        
+
         GET /api/currencies/supported/?provider=nowpayments&currency_type=crypto
         """
         serializer = SupportedCurrenciesSerializer(data=request.query_params)
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
 
 
@@ -194,18 +236,18 @@ class NetworkViewSet(ReadOnlyPaymentViewSet):
     
     Read-only access to blockchain network information.
     """
-    
+
     queryset = Network.objects.filter(is_active=True)
     serializer_class = NetworkSerializer
     permission_classes = [permissions.IsAuthenticated]
     filterset_fields = ['native_currency__code', 'is_active']
     search_fields = ['name', 'code']
     ordering_fields = ['name', 'code', 'created_at']
-    
+
     def get_queryset(self):
         """Optimize queryset with related objects."""
         return super().get_queryset().select_related('native_currency')
-    
+
     @action(detail=False, methods=['get'])
     def by_currency(self, request):
         """
@@ -215,7 +257,7 @@ class NetworkViewSet(ReadOnlyPaymentViewSet):
         """
         try:
             queryset = self.filter_queryset(self.get_queryset())
-            
+
             networks_by_currency = {}
             for network in queryset:
                 currency_code = network.native_currency.code
@@ -225,17 +267,17 @@ class NetworkViewSet(ReadOnlyPaymentViewSet):
                         'currency': CurrencyListSerializer(network.native_currency).data,
                         'networks': []
                     }
-                
+
                 networks_by_currency[currency_code]['networks'].append(
                     NetworkSerializer(network).data
                 )
-            
+
             return Response({
                 'networks_by_currency': networks_by_currency,
                 'total_currencies': len(networks_by_currency),
                 'generated_at': timezone.now().isoformat()
             })
-            
+
         except Exception as e:
             logger.error(f"Networks by currency failed: {e}")
             return Response(
@@ -250,55 +292,68 @@ class ProviderCurrencyViewSet(ReadOnlyPaymentViewSet):
     
     Read-only access to provider-specific currency information.
     """
-    
+
     queryset = ProviderCurrency.objects.filter(is_enabled=True)
     serializer_class = ProviderCurrencySerializer
     permission_classes = [permissions.IsAuthenticated]
     filterset_fields = ['provider', 'currency__code', 'network__code', 'is_enabled']
     search_fields = ['provider_currency_code']
     ordering_fields = ['provider', 'created_at']
-    
+
     def get_queryset(self):
         """Optimize queryset with related objects."""
         return super().get_queryset().select_related('currency', 'network')
-    
+
+    @extend_schema(
+        parameters=[
+            OpenApiParameter(
+                name='provider',
+                type=OpenApiTypes.STR,
+                location=OpenApiParameter.QUERY,
+                description='Filter by payment provider (e.g., nowpayments)',
+                required=False,
+            ),
+        ],
+        summary='Get provider currencies grouped by provider',
+        description='Get provider currencies grouped by provider',
+    )
     @action(detail=False, methods=['get'])
     def by_provider(self, request):
         """
         Get provider currencies grouped by provider.
-        
+
         GET /api/provider-currencies/by_provider/
         """
         try:
             queryset = self.filter_queryset(self.get_queryset())
-            
+
             currencies_by_provider = {}
             for provider_currency in queryset:
                 provider = provider_currency.provider
-                
+
                 if provider not in currencies_by_provider:
                     currencies_by_provider[provider] = {
                         'provider': provider,
                         'currencies': []
                     }
-                
+
                 currencies_by_provider[provider]['currencies'].append(
                     ProviderCurrencySerializer(provider_currency).data
                 )
-            
+
             return Response({
                 'currencies_by_provider': currencies_by_provider,
                 'total_providers': len(currencies_by_provider),
                 'generated_at': timezone.now().isoformat()
             })
-            
+
         except Exception as e:
             logger.error(f"Provider currencies by provider failed: {e}")
             return Response(
                 {'error': f'Provider currencies by provider failed: {e}'},
                 status=status.HTTP_500_INTERNAL_SERVER_ERROR
             )
-    
+
     @action(detail=False, methods=['get'])
     def limits(self, request):
         """
@@ -308,16 +363,16 @@ class ProviderCurrencyViewSet(ReadOnlyPaymentViewSet):
         """
         try:
             queryset = self.filter_queryset(self.get_queryset())
-            
+
             provider_filter = request.query_params.get('provider')
             if provider_filter:
                 queryset = queryset.filter(provider=provider_filter)
-            
+
             limits = {}
             for provider_currency in queryset:
                 currency_code = provider_currency.currency.code
                 provider = provider_currency.provider
-                
+
                 key = f"{provider}_{currency_code}"
                 limits[key] = {
                     'provider': provider,
@@ -326,13 +381,13 @@ class ProviderCurrencyViewSet(ReadOnlyPaymentViewSet):
                     'max_amount': provider_currency.provider_max_amount_usd,
                     'fee_percentage': provider_currency.provider_fee_percentage,
                 }
-            
+
             return Response({
                 'limits': limits,
                 'count': len(limits),
                 'generated_at': timezone.now().isoformat()
             })
-            
+
         except Exception as e:
             logger.error(f"Currency limits failed: {e}")
             return Response(
@@ -348,18 +403,18 @@ class CurrencyConversionView(generics.GenericAPIView):
     
     Simplified endpoint for currency conversion.
     """
-    
+
     serializer_class = CurrencyConversionSerializer
     permission_classes = [permissions.IsAuthenticated]
-    
+
     def post(self, request, *args, **kwargs):
         """Convert between currencies."""
         serializer = self.get_serializer(data=request.data)
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
 
 
@@ -369,18 +424,18 @@ class CurrencyRatesView(generics.GenericAPIView):
     
     Simplified endpoint for getting exchange rates.
     """
-    
+
     serializer_class = CurrencyRatesSerializer
     permission_classes = [permissions.IsAuthenticated]
-    
+
     def get(self, request, *args, **kwargs):
         """Get current exchange rates."""
         serializer = self.get_serializer(data=request.query_params)
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
 
 
@@ -390,16 +445,16 @@ class SupportedCurrenciesView(generics.GenericAPIView):
     
     Simplified endpoint for getting supported currencies.
     """
-    
+
     serializer_class = SupportedCurrenciesSerializer
     permission_classes = [permissions.IsAuthenticated]
-    
+
     def get(self, request, *args, **kwargs):
         """Get supported currencies from providers."""
         serializer = self.get_serializer(data=request.query_params)
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
