@@ -4,28 +4,27 @@ Subscription ViewSets for the Universal Payment System v2.0.
 DRF ViewSets for subscription management with service integration.
 """
 
-from rest_framework import viewsets, permissions, status
-from rest_framework.decorators import action
-from rest_framework.response import Response
-from django_filters.rest_framework import DjangoFilterBackend
 from django.contrib.auth import get_user_model
 from django.db import models
 from django.utils import timezone
+from rest_framework import permissions, status
+from rest_framework.decorators import action
+from rest_framework.response import Response
 
-from .base import PaymentBaseViewSet, NestedPaymentViewSet, ReadOnlyPaymentViewSet
-from ...models import Subscription, EndpointGroup, Tariff
-from ...services import get_subscription_service
+from django_cfg.modules.django_logging import get_logger
+
+from ...models import EndpointGroup, Subscription, Tariff
 from ..serializers.subscriptions import (
-    SubscriptionSerializer,
+    EndpointGroupSerializer,
     SubscriptionCreateSerializer,
     SubscriptionListSerializer,
+    SubscriptionSerializer,
+    SubscriptionStatsSerializer,
     SubscriptionUpdateSerializer,
     SubscriptionUsageSerializer,
-    SubscriptionStatsSerializer,
-    EndpointGroupSerializer,
     TariffSerializer,
 )
-from django_cfg.modules.django_logging import get_logger
+from .base import NestedPaymentViewSet, PaymentBaseViewSet, ReadOnlyPaymentViewSet
 
 User = get_user_model()
 logger = get_logger("subscription_viewsets")
@@ -37,14 +36,14 @@ class SubscriptionViewSet(PaymentBaseViewSet):
     
     Provides admin-level access to all subscriptions with filtering and stats.
     """
-    
+
     queryset = Subscription.objects.all()
     serializer_class = SubscriptionSerializer
     permission_classes = [permissions.IsAuthenticated]  # Allow authenticated users
     filterset_fields = ['status', 'tier', 'user']
     search_fields = ['user__username', 'user__email']
     ordering_fields = ['created_at', 'updated_at', 'expires_at', 'total_requests']
-    
+
     serializer_classes = {
         'list': SubscriptionListSerializer,
         'create': SubscriptionCreateSerializer,
@@ -52,7 +51,7 @@ class SubscriptionViewSet(PaymentBaseViewSet):
         'update': SubscriptionSerializer,
         'partial_update': SubscriptionSerializer,
     }
-    
+
     def get_queryset(self):
         """Optimized queryset with related objects."""
         queryset = super().get_queryset().select_related(
@@ -60,13 +59,13 @@ class SubscriptionViewSet(PaymentBaseViewSet):
         ).prefetch_related(
             'endpoint_groups'
         )
-        
+
         # Non-staff users can only see their own subscriptions
         if not self.request.user.is_staff:
             queryset = queryset.filter(user=self.request.user)
-        
+
         return queryset
-    
+
     @action(detail=True, methods=['post'])
     def update_status(self, request, pk=None):
         """
@@ -75,7 +74,7 @@ class SubscriptionViewSet(PaymentBaseViewSet):
         POST /api/subscriptions/{id}/update_status/
         """
         subscription = self.get_object()
-        
+
         serializer = SubscriptionUpdateSerializer(
             data=request.data,
             context={
@@ -83,13 +82,13 @@ class SubscriptionViewSet(PaymentBaseViewSet):
                 'subscription_id': str(subscription.id)
             }
         )
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-    
+
     @action(detail=True, methods=['post'])
     def increment_usage(self, request, pk=None):
         """
@@ -98,7 +97,7 @@ class SubscriptionViewSet(PaymentBaseViewSet):
         POST /api/subscriptions/{id}/increment_usage/
         """
         subscription = self.get_object()
-        
+
         serializer = SubscriptionUsageSerializer(
             data=request.data,
             context={
@@ -106,13 +105,13 @@ class SubscriptionViewSet(PaymentBaseViewSet):
                 'subscription_id': str(subscription.id)
             }
         )
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-    
+
     @action(detail=False, methods=['get'])
     def analytics(self, request):
         """
@@ -121,13 +120,13 @@ class SubscriptionViewSet(PaymentBaseViewSet):
         GET /api/subscriptions/analytics/?days=30
         """
         serializer = SubscriptionStatsSerializer(data=request.query_params)
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-    
+
     @action(detail=False, methods=['get'])
     def by_status(self, request):
         """
@@ -137,14 +136,14 @@ class SubscriptionViewSet(PaymentBaseViewSet):
         """
         try:
             queryset = self.filter_queryset(self.get_queryset())
-            
+
             status_stats = {}
             for status_choice in Subscription.SubscriptionStatus.choices:
                 status_code = status_choice[0]
                 status_name = status_choice[1]
-                
+
                 status_subscriptions = queryset.filter(status=status_code)
-                
+
                 status_stats[status_code] = {
                     'name': status_name,
                     'total_subscriptions': status_subscriptions.count(),
@@ -153,19 +152,19 @@ class SubscriptionViewSet(PaymentBaseViewSet):
                     )['total'] or 0,
                     'active_users': status_subscriptions.values('user').distinct().count(),
                 }
-            
+
             return Response({
                 'status_stats': status_stats,
                 'generated_at': timezone.now().isoformat()
             })
-            
+
         except Exception as e:
             logger.error(f"Subscription status stats failed: {e}")
             return Response(
                 {'error': f'Status stats failed: {e}'},
                 status=status.HTTP_500_INTERNAL_SERVER_ERROR
             )
-    
+
     @action(detail=False, methods=['get'])
     def by_tier(self, request):
         """
@@ -175,14 +174,14 @@ class SubscriptionViewSet(PaymentBaseViewSet):
         """
         try:
             queryset = self.filter_queryset(self.get_queryset())
-            
+
             tier_stats = {}
             for tier_choice in Subscription.SubscriptionTier.choices:
                 tier_code = tier_choice[0]
                 tier_name = tier_choice[1]
-                
+
                 tier_subscriptions = queryset.filter(tier=tier_code)
-                
+
                 tier_stats[tier_code] = {
                     'name': tier_name,
                     'total_subscriptions': tier_subscriptions.count(),
@@ -193,12 +192,12 @@ class SubscriptionViewSet(PaymentBaseViewSet):
                         total=models.Sum('total_requests')
                     )['total'] or 0,
                 }
-            
+
             return Response({
                 'tier_stats': tier_stats,
                 'generated_at': timezone.now().isoformat()
             })
-            
+
         except Exception as e:
             logger.error(f"Subscription tier stats failed: {e}")
             return Response(
@@ -213,36 +212,36 @@ class UserSubscriptionViewSet(NestedPaymentViewSet):
     
     Provides user-scoped access to subscriptions with full CRUD operations.
     """
-    
+
     queryset = Subscription.objects.all()
     serializer_class = SubscriptionSerializer
     permission_classes = [permissions.IsAuthenticated]
     filterset_fields = ['status', 'tier']
     search_fields = []
     ordering_fields = ['created_at', 'updated_at', 'expires_at']
-    
+
     # Nested ViewSet configuration
     parent_lookup_field = 'user_pk'
     parent_model_field = 'user'
-    
+
     serializer_classes = {
         'list': SubscriptionListSerializer,
         'create': SubscriptionCreateSerializer,
         'retrieve': SubscriptionSerializer,
     }
-    
+
     def get_queryset(self):
         """Filter by user and optimize queryset."""
         queryset = super().get_queryset()
-        
+
         # Additional permission check: users can only see their own subscriptions
         if not self.request.user.is_staff:
             user_id = self.kwargs.get('user_pk')
             if str(self.request.user.id) != str(user_id):
                 return queryset.none()
-        
+
         return queryset.select_related('user').prefetch_related('endpoint_groups')
-    
+
     @action(detail=True, methods=['post'])
     def update_status(self, request, user_pk=None, pk=None):
         """
@@ -251,7 +250,7 @@ class UserSubscriptionViewSet(NestedPaymentViewSet):
         POST /api/users/{user_id}/subscriptions/{id}/update_status/
         """
         subscription = self.get_object()
-        
+
         serializer = SubscriptionUpdateSerializer(
             data=request.data,
             context={
@@ -259,13 +258,13 @@ class UserSubscriptionViewSet(NestedPaymentViewSet):
                 'subscription_id': str(subscription.id)
             }
         )
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-    
+
     @action(detail=True, methods=['post'])
     def increment_usage(self, request, user_pk=None, pk=None):
         """
@@ -274,7 +273,7 @@ class UserSubscriptionViewSet(NestedPaymentViewSet):
         POST /api/users/{user_id}/subscriptions/{id}/increment_usage/
         """
         subscription = self.get_object()
-        
+
         serializer = SubscriptionUsageSerializer(
             data=request.data,
             context={
@@ -282,13 +281,13 @@ class UserSubscriptionViewSet(NestedPaymentViewSet):
                 'subscription_id': str(subscription.id)
             }
         )
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-    
+
     @action(detail=False, methods=['get'])
     def active(self, request, user_pk=None):
         """
@@ -301,7 +300,7 @@ class UserSubscriptionViewSet(NestedPaymentViewSet):
             active_subscription = queryset.filter(
                 status=Subscription.SubscriptionStatus.ACTIVE
             ).first()
-            
+
             if active_subscription:
                 serializer = self.get_serializer(active_subscription)
                 return Response({
@@ -315,14 +314,14 @@ class UserSubscriptionViewSet(NestedPaymentViewSet):
                     'subscription': None,
                     'message': 'No active subscription found'
                 })
-                
+
         except Exception as e:
             logger.error(f"Active subscription lookup failed: {e}")
             return Response(
                 {'error': f'Active subscription lookup failed: {e}'},
                 status=status.HTTP_500_INTERNAL_SERVER_ERROR
             )
-    
+
     @action(detail=False, methods=['get'])
     def summary(self, request, user_pk=None):
         """
@@ -332,7 +331,7 @@ class UserSubscriptionViewSet(NestedPaymentViewSet):
         """
         try:
             queryset = self.filter_queryset(self.get_queryset())
-            
+
             summary = queryset.aggregate(
                 total_subscriptions=models.Count('id'),
                 active_subscriptions=models.Count(
@@ -345,7 +344,7 @@ class UserSubscriptionViewSet(NestedPaymentViewSet):
                 ),
                 total_requests=models.Sum('total_requests'),
             )
-            
+
             return Response({
                 'user_id': user_pk,
                 'summary': {
@@ -354,7 +353,7 @@ class UserSubscriptionViewSet(NestedPaymentViewSet):
                 },
                 'generated_at': timezone.now().isoformat()
             })
-            
+
         except Exception as e:
             logger.error(f"User subscription summary failed: {e}")
             return Response(
@@ -369,14 +368,14 @@ class EndpointGroupViewSet(ReadOnlyPaymentViewSet):
     
     Read-only access to endpoint group information.
     """
-    
+
     queryset = EndpointGroup.objects.filter(is_enabled=True)
     serializer_class = EndpointGroupSerializer
     permission_classes = [permissions.IsAuthenticated]
     filterset_fields = ['is_enabled']
     search_fields = ['name', 'description']
     ordering_fields = ['name', 'created_at']
-    
+
     @action(detail=False, methods=['get'])
     def available(self, request):
         """
@@ -387,13 +386,13 @@ class EndpointGroupViewSet(ReadOnlyPaymentViewSet):
         try:
             queryset = self.filter_queryset(self.get_queryset())
             serializer = self.get_serializer(queryset, many=True)
-            
+
             return Response({
                 'endpoint_groups': serializer.data,
                 'count': len(serializer.data),
                 'generated_at': timezone.now().isoformat()
             })
-            
+
         except Exception as e:
             logger.error(f"Available endpoint groups failed: {e}")
             return Response(
@@ -408,18 +407,18 @@ class TariffViewSet(ReadOnlyPaymentViewSet):
     
     Read-only access to tariff information for subscription selection.
     """
-    
+
     queryset = Tariff.objects.filter(is_active=True)
     serializer_class = TariffSerializer
     permission_classes = [permissions.IsAuthenticated]
     filterset_fields = ['is_active']
     search_fields = ['name', 'description']
     ordering_fields = ['monthly_price', 'requests_per_month', 'created_at']
-    
+
     def get_queryset(self):
         """Optimize queryset with related objects."""
         return super().get_queryset().prefetch_related('endpoint_groups')
-    
+
     @action(detail=False, methods=['get'])
     def free(self, request):
         """
@@ -429,14 +428,14 @@ class TariffViewSet(ReadOnlyPaymentViewSet):
         """
         free_tariffs = self.get_queryset().filter(monthly_price_usd=0)
         serializer = self.get_serializer(free_tariffs, many=True)
-        
+
         return Response({
             'tariffs': serializer.data,
             'count': len(serializer.data),
             'type': 'free',
             'generated_at': timezone.now().isoformat()
         })
-    
+
     @action(detail=False, methods=['get'])
     def paid(self, request):
         """
@@ -446,14 +445,14 @@ class TariffViewSet(ReadOnlyPaymentViewSet):
         """
         paid_tariffs = self.get_queryset().filter(monthly_price_usd__gt=0)
         serializer = self.get_serializer(paid_tariffs, many=True)
-        
+
         return Response({
             'tariffs': serializer.data,
             'count': len(serializer.data),
             'type': 'paid',
             'generated_at': timezone.now().isoformat()
         })
-    
+
     @action(detail=True, methods=['get'])
     def endpoint_groups(self, request, pk=None):
         """
@@ -464,7 +463,7 @@ class TariffViewSet(ReadOnlyPaymentViewSet):
         tariff = self.get_object()
         endpoint_groups = tariff.endpoint_groups.filter(is_active=True)
         serializer = EndpointGroupSerializer(endpoint_groups, many=True)
-        
+
         return Response({
             'tariff': {
                 'id': tariff.id,
