@@ -5,23 +5,31 @@ Handles incoming webhooks from payment providers with universal support.
 """
 
 import json
-import logging
-from typing import Dict, Any, Optional
-from django.http import JsonResponse, HttpRequest
+from typing import Any, Dict, Optional
+
+from django.http import HttpRequest, JsonResponse
+from django.utils import timezone
+from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import csrf_exempt
 from django.views.decorators.http import require_http_methods
-from django.utils.decorators import method_decorator
-from django.utils import timezone
+from drf_spectacular.utils import OpenApiParameter, OpenApiTypes, extend_schema
 from rest_framework import status
 from rest_framework.decorators import api_view, permission_classes
 from rest_framework.permissions import AllowAny
 from rest_framework.response import Response
 from rest_framework.views import APIView
 
-from ...services.core.webhook_service import WebhookService
-from ...services.types import WebhookValidationRequest, WebhookProcessingResult
 from django_cfg.modules.django_logging import get_logger
 
+from ...services.core.webhook_service import WebhookService
+from ...services.types import WebhookProcessingResult, WebhookValidationRequest
+from ..serializers.webhooks import (
+    SupportedProvidersSerializer,
+    WebhookHealthSerializer,
+    WebhookResponseSerializer,
+    WebhookStatsSerializer,
+)
+
 logger = get_logger("webhook_views")
 
 
@@ -29,7 +37,7 @@ logger = get_logger("webhook_views")
 class UniversalWebhookView(APIView):
     """
     Universal webhook handler for all payment providers.
-    
+
     Features:
     - Provider-agnostic webhook processing
     - Signature validation and security
@@ -37,13 +45,29 @@ class UniversalWebhookView(APIView):
     - Comprehensive logging and monitoring
     - Integration with ngrok for development
     """
-    
+
     permission_classes = [AllowAny]  # Webhooks don't use standard auth
-    
+    serializer_class = WebhookResponseSerializer  # For OpenAPI schema generation
+
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         self.webhook_service = WebhookService()
-    
+
+    @extend_schema(
+        summary="Process Webhook",
+        description="Process incoming webhook from payment provider",
+        parameters=[
+            OpenApiParameter(
+                name='provider',
+                description='Payment provider name (nowpayments, stripe, etc.)',
+                required=True,
+                type=OpenApiTypes.STR,
+                location=OpenApiParameter.PATH
+            )
+        ],
+        responses={200: WebhookResponseSerializer},
+        tags=["Webhooks"]
+    )
     def post(self, request: HttpRequest, provider: str) -> JsonResponse:
         """
         Handle incoming webhook from any payment provider.
@@ -55,18 +79,18 @@ class UniversalWebhookView(APIView):
         Returns:
             JsonResponse: Processing result
         """
-        
+
         start_time = timezone.now()
         request_id = self._generate_request_id()
-        
-        logger.info(f"📥 Webhook received", extra={
+
+        logger.info("📥 Webhook received", extra={
             'provider': provider,
             'request_id': request_id,
             'content_type': request.content_type,
             'content_length': len(request.body) if request.body else 0,
             'user_agent': request.META.get('HTTP_USER_AGENT', 'unknown')
         })
-        
+
         try:
             # Parse webhook payload
             webhook_payload = self._parse_webhook_payload(request)
@@ -76,13 +100,13 @@ class UniversalWebhookView(APIView):
                     status.HTTP_400_BAD_REQUEST,
                     request_id
                 )
-            
+
             # Extract headers for signature validation
             webhook_headers = self._extract_webhook_headers(request)
-            
+
             # Get signature from headers (provider-specific)
             signature = self._extract_signature(provider, webhook_headers)
-            
+
             # Create validation request
             validation_request = WebhookValidationRequest(
                 provider=provider,
@@ -92,14 +116,14 @@ class UniversalWebhookView(APIView):
                 timestamp=start_time.isoformat(),
                 request_id=request_id
             )
-            
+
             # Process webhook
             result = self.webhook_service.process_webhook(validation_request)
-            
+
             # Log processing result
             processing_time = (timezone.now() - start_time).total_seconds()
-            
-            logger.info(f"🔄 Webhook processed", extra={
+
+            logger.info("🔄 Webhook processed", extra={
                 'provider': provider,
                 'request_id': request_id,
                 'success': result.success,
@@ -107,7 +131,7 @@ class UniversalWebhookView(APIView):
                 'actions_taken': getattr(result, 'actions_taken', []),
                 'payment_id': getattr(result, 'payment_id', None)
             })
-            
+
             # Return appropriate response
             if result.success:
                 return self._success_response(result, request_id)
@@ -118,9 +142,9 @@ class UniversalWebhookView(APIView):
                     request_id,
                     result
                 )
-                
+
         except json.JSONDecodeError as e:
-            logger.warning(f"Invalid JSON payload", extra={
+            logger.warning("Invalid JSON payload", extra={
                 'provider': provider,
                 'request_id': request_id,
                 'error': str(e)
@@ -130,9 +154,9 @@ class UniversalWebhookView(APIView):
                 status.HTTP_400_BAD_REQUEST,
                 request_id
             )
-            
+
         except Exception as e:
-            logger.error(f"Webhook processing error", extra={
+            logger.error("Webhook processing error", extra={
                 'provider': provider,
                 'request_id': request_id,
                 'error': str(e),
@@ -143,22 +167,37 @@ class UniversalWebhookView(APIView):
                 status.HTTP_500_INTERNAL_SERVER_ERROR,
                 request_id
             )
-    
+
+    @extend_schema(
+        summary="Webhook Endpoint Info",
+        description="Get webhook endpoint information for debugging and configuration",
+        parameters=[
+            OpenApiParameter(
+                name='provider',
+                description='Payment provider name',
+                required=True,
+                type=OpenApiTypes.STR,
+                location=OpenApiParameter.PATH
+            )
+        ],
+        responses={200: WebhookResponseSerializer},
+        tags=["Webhooks"]
+    )
     def get(self, request: HttpRequest, provider: str) -> JsonResponse:
         """
         Handle GET requests for webhook endpoint info.
-        
+
         Useful for debugging and provider configuration verification.
         """
-        
-        logger.info(f"📋 Webhook info requested", extra={
+
+        logger.info("📋 Webhook info requested", extra={
             'provider': provider,
             'ip': self._get_client_ip(request)
         })
-        
+
         # Get webhook URL using ngrok integration
         webhook_url = self._get_webhook_url(request, provider)
-        
+
         info = {
             'provider': provider,
             'webhook_url': webhook_url,
@@ -167,20 +206,20 @@ class UniversalWebhookView(APIView):
             'timestamp': timezone.now().isoformat(),
             'service_status': 'active'
         }
-        
+
         return JsonResponse(info, status=status.HTTP_200_OK)
-    
+
     # ===== HELPER METHODS =====
-    
+
     def _parse_webhook_payload(self, request: HttpRequest) -> Optional[Dict[str, Any]]:
         """Parse webhook payload from request body."""
         try:
             if not request.body:
                 return None
-            
+
             # Handle different content types
             content_type = request.content_type.lower()
-            
+
             if 'application/json' in content_type:
                 return json.loads(request.body.decode('utf-8'))
             elif 'application/x-www-form-urlencoded' in content_type:
@@ -192,31 +231,31 @@ class UniversalWebhookView(APIView):
             else:
                 # Try JSON as fallback
                 return json.loads(request.body.decode('utf-8'))
-                
+
         except (json.JSONDecodeError, UnicodeDecodeError) as e:
             logger.warning(f"Failed to parse webhook payload: {e}")
             return None
-    
+
     def _extract_webhook_headers(self, request: HttpRequest) -> Dict[str, str]:
         """Extract relevant headers for webhook validation."""
         headers = {}
-        
+
         # Extract all HTTP headers
         for key, value in request.META.items():
             if key.startswith('HTTP_'):
                 # Convert HTTP_X_CUSTOM_HEADER to x-custom-header
                 header_name = key[5:].lower().replace('_', '-')
                 headers[header_name] = value
-        
+
         # Add some non-HTTP headers that might be useful
         headers['content-type'] = request.content_type
         headers['content-length'] = str(len(request.body)) if request.body else '0'
-        
+
         return headers
-    
+
     def _extract_signature(self, provider: str, headers: Dict[str, str]) -> Optional[str]:
         """Extract signature from headers based on provider."""
-        
+
         # Provider-specific signature header mapping
         signature_headers = {
             'nowpayments': 'x-nowpayments-sig',
@@ -224,52 +263,52 @@ class UniversalWebhookView(APIView):
             'cryptapi': 'x-cryptapi-signature',
             'cryptomus': 'sign',
         }
-        
+
         signature_header = signature_headers.get(provider.lower())
         if signature_header:
             return headers.get(signature_header)
-        
+
         # Fallback: look for common signature headers
         common_headers = ['signature', 'x-signature', 'authorization']
         for header in common_headers:
             if header in headers:
                 return headers[header]
-        
+
         return None
-    
+
     def _get_expected_headers(self, provider: str) -> Dict[str, str]:
         """Get expected headers for each provider."""
         from ...services.integrations import get_webhook_provider_info, is_provider_supported
-        
+
         if not is_provider_supported(provider):
             return {'content-type': 'application/json'}
-        
+
         provider_info = get_webhook_provider_info(provider)
         return {
             provider_info.signature_header: f'{provider_info.signature_algorithm} signature',
             'content-type': provider_info.content_type
         }
-    
+
     def _get_webhook_url(self, request: HttpRequest, provider: str) -> str:
         """Get webhook URL using ngrok integration."""
         from ...services.integrations import get_webhook_url_for_provider
         return get_webhook_url_for_provider(provider)
-    
+
     def _generate_request_id(self) -> str:
         """Generate unique request ID for tracking."""
         import uuid
         return str(uuid.uuid4())[:8]
-    
+
     def _get_client_ip(self, request: HttpRequest) -> str:
         """Get client IP address."""
         x_forwarded_for = request.META.get('HTTP_X_FORWARDED_FOR')
         if x_forwarded_for:
             return x_forwarded_for.split(',')[0].strip()
         return request.META.get('REMOTE_ADDR', 'unknown')
-    
+
     def _success_response(self, result: WebhookProcessingResult, request_id: str) -> JsonResponse:
         """Create success response."""
-        
+
         response_data = {
             'success': True,
             'message': 'Webhook processed successfully',
@@ -278,64 +317,70 @@ class UniversalWebhookView(APIView):
             'processed': result.processed,
             'timestamp': timezone.now().isoformat()
         }
-        
+
         # Add optional fields if available
         if hasattr(result, 'payment_id') and result.payment_id:
             response_data['payment_id'] = result.payment_id
-        
+
         if hasattr(result, 'actions_taken') and result.actions_taken:
             response_data['actions_taken'] = result.actions_taken
-        
+
         if hasattr(result, 'status_after') and result.status_after:
             response_data['payment_status'] = result.status_after
-        
+
         return JsonResponse(response_data, status=status.HTTP_200_OK)
-    
+
     def _error_response(
-        self, 
-        message: str, 
-        status_code: int, 
+        self,
+        message: str,
+        status_code: int,
         request_id: str,
         result: Optional[WebhookProcessingResult] = None
     ) -> JsonResponse:
         """Create error response."""
-        
+
         response_data = {
             'success': False,
             'error': message,
             'request_id': request_id,
             'timestamp': timezone.now().isoformat()
         }
-        
+
         if result:
             response_data['provider'] = result.provider
             response_data['processed'] = getattr(result, 'processed', False)
-        
+
         return JsonResponse(response_data, status=status_code)
 
 
+@extend_schema(
+    summary="Webhook Health Check",
+    description="Check webhook service health status and recent activity metrics",
+    responses={200: WebhookHealthSerializer},
+    tags=["Webhooks"]
+)
 @api_view(['GET'])
 @permission_classes([AllowAny])
 def webhook_health_check(request):
     """
     Health check endpoint for webhook service.
-    
+
     Returns service status and recent activity metrics.
     """
-    
+
     try:
-        from ...services.integrations import is_ngrok_available, get_api_base_url
-        
+        from ...services.integrations import get_api_base_url, is_ngrok_available
+
         webhook_service = WebhookService()
         health_result = webhook_service.health_check()
-        
+
         # Add ngrok status
         health_data = health_result.data if health_result.success else {}
         health_data.update({
             'ngrok_available': is_ngrok_available(),
             'api_base_url': get_api_base_url(),
         })
-        
+
         if health_result.success:
             return Response({
                 'status': 'healthy',
@@ -351,7 +396,7 @@ def webhook_health_check(request):
                 'timestamp': timezone.now().isoformat(),
                 'details': health_data
             }, status=status.HTTP_503_SERVICE_UNAVAILABLE)
-            
+
     except Exception as e:
         logger.error(f"Webhook health check failed: {e}")
         return Response({
@@ -362,24 +407,39 @@ def webhook_health_check(request):
         }, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
 
 
+@extend_schema(
+    summary="Webhook Statistics",
+    description="Get webhook processing statistics for a given time period",
+    parameters=[
+        OpenApiParameter(
+            name='days',
+            description='Number of days to analyze (1-365)',
+            required=False,
+            type=OpenApiTypes.INT,
+            default=30
+        )
+    ],
+    responses={200: WebhookStatsSerializer},
+    tags=["Webhooks"]
+)
 @api_view(['GET'])
 @permission_classes([AllowAny])
 def webhook_stats(request):
     """
     Get webhook processing statistics.
-    
+
     Query parameters:
     - days: Number of days to analyze (default: 30)
     """
-    
+
     try:
         days = int(request.GET.get('days', 30))
         if days < 1 or days > 365:
             days = 30
-        
+
         webhook_service = WebhookService()
         stats_result = webhook_service.get_webhook_stats(days)
-        
+
         if stats_result.success:
             return Response({
                 'success': True,
@@ -392,7 +452,7 @@ def webhook_stats(request):
                 'error': stats_result.message,
                 'timestamp': timezone.now().isoformat()
             }, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
-            
+
     except ValueError:
         return Response({
             'success': False,
@@ -408,22 +468,28 @@ def webhook_stats(request):
         }, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
 
 
+@extend_schema(
+    summary="Supported Webhook Providers",
+    description="Get list of supported webhook providers with configuration details",
+    responses={200: SupportedProvidersSerializer},
+    tags=["Webhooks"]
+)
 @api_view(['GET'])
 @permission_classes([AllowAny])
 def supported_providers(request):
     """
     Get list of supported webhook providers.
-    
+
     Returns provider information and webhook URLs.
     """
-    
+
     try:
-        from ...services.integrations import get_all_webhook_urls, get_all_providers_info
-        
+        from ...services.integrations import get_all_providers_info, get_all_webhook_urls
+
         # Get all providers info dynamically
         providers_info = get_all_providers_info()
         webhook_urls = get_all_webhook_urls()
-        
+
         # Build provider list
         providers_list = []
         for provider_name, info in providers_info.items():
@@ -435,14 +501,14 @@ def supported_providers(request):
                 'webhook_url': webhook_urls.get(provider_name, f"http://localhost:8000/api/webhooks/{provider_name}/"),
                 'content_type': info['content_type']
             })
-        
+
         return Response({
             'success': True,
             'providers': providers_list,
             'total_count': len(providers_list),
             'timestamp': timezone.now().isoformat()
         }, status=status.HTTP_200_OK)
-        
+
     except Exception as e:
         logger.error(f"Supported providers endpoint failed: {e}")
         return Response({
@@ -462,9 +528,9 @@ def webhook_handler(request, provider: str):
     
     Delegates to UniversalWebhookView for actual processing.
     """
-    
+
     view = UniversalWebhookView()
-    
+
     if request.method == 'POST':
         return view.post(request, provider)
     elif request.method == 'GET':
