@@ -4,10 +4,15 @@ Django CFG API URLs
 Built-in API endpoints for django_cfg functionality.
 """
 
+import traceback
 from typing import List
 
 from django.urls import include, path
 
+from django_cfg.modules.django_logging import get_logger, sanitize_extra
+
+logger = get_logger(__name__)
+
 
 def get_enabled_cfg_apps() -> List[str]:
     """
@@ -85,10 +90,39 @@ def get_default_cfg_group():
 
 
 def _safe_include(pattern_path: str, module_path: str):
-    """Helper to safely include URL module if it exists."""
+    """
+    Helper to safely include URL module if it exists.
+
+    Args:
+        pattern_path: URL pattern (e.g., 'cfg/knowbase/')
+        module_path: Module path (e.g., 'django_cfg.apps.knowbase.urls')
+
+    Returns:
+        URLPattern if successful, None if import fails
+    """
     try:
         return path(pattern_path, include(module_path))
-    except ImportError:
+    except ImportError as e:
+        logger.warning(
+            f"Failed to import URL module '{module_path}' for pattern '{pattern_path}': {e}",
+            extra=sanitize_extra({
+                'pattern': pattern_path,
+                'module': module_path,
+                'error': str(e),
+            })
+        )
+        logger.debug(f"Traceback for '{module_path}':\n{traceback.format_exc()}")
+        return None
+    except Exception as e:
+        logger.error(
+            f"Unexpected error including URL module '{module_path}' for pattern '{pattern_path}': {e}",
+            extra=sanitize_extra({
+                'pattern': pattern_path,
+                'module': module_path,
+                'error': str(e),
+                'traceback': traceback.format_exc(),
+            })
+        )
         return None
 
 
