@@ -10,27 +10,28 @@ This module contains ONLY the data model definition:
 Total size: ~350 lines (down from 903 in original config.py)
 """
 
-from typing import Dict, List, Optional, Any
 from pathlib import Path
-from pydantic import BaseModel, Field, field_validator, model_validator, PrivateAttr
+from typing import Any, Dict, List, Optional
 
-from ..types.enums import EnvironmentMode, StartupInfoMode
-from ..exceptions import ConfigurationError, ValidationError
+from pydantic import BaseModel, Field, PrivateAttr, field_validator, model_validator
+
+from ...apps.ipc import DjangoCfgRPCConfig
 from ...models import (
-    DatabaseConfig,
+    ApiKeys,
     CacheConfig,
+    DatabaseConfig,
+    DRFConfig,
     EmailConfig,
+    LimitsConfig,
+    SpectacularConfig,
     TelegramConfig,
     UnfoldConfig,
-    DRFConfig,
-    SpectacularConfig,
-    LimitsConfig,
-    ApiKeys,
 )
-from ...models.tasks import TaskConfig
-from ...models.payments import PaymentsConfig
 from ...models.ngrok import NgrokConfig
-from ...modules.django_ipc_client.config import DjangoCfgRPCConfig
+from ...models.payments import PaymentsConfig
+from ...models.tasks import TaskConfig
+from ..exceptions import ConfigurationError
+from ..types.enums import EnvironmentMode, StartupInfoMode
 
 
 class DjangoConfig(BaseModel):
@@ -313,12 +314,12 @@ class DjangoConfig(BaseModel):
     # === API Configuration ===
     drf: Optional[DRFConfig] = Field(
         default=None,
-        description="Extended Django REST Framework configuration (supplements Revolution)",
+        description="Extended Django REST Framework configuration (supplements OpenAPI Client)",
     )
 
     spectacular: Optional[SpectacularConfig] = Field(
         default=None,
-        description="Extended DRF Spectacular configuration (supplements Revolution)",
+        description="Extended DRF Spectacular configuration (supplements OpenAPI Client)",
     )
 
     # === Limits Configuration ===
@@ -483,14 +484,14 @@ class DjangoConfig(BaseModel):
         """
         Get the base directory of the project.
 
-        Looks for manage.py in current directory and parents.
+        Looks for manage.py starting from current working directory and going up.
         Falls back to current working directory if not found.
+        
+        This ensures we find the Django project root, not the django-cfg package location.
         """
         if self._base_dir is None:
-            import os
-
-            # Start from current working directory
-            current_path = Path(os.path.dirname(os.path.abspath(__file__)))
+            # Start from current working directory (where Django runs)
+            current_path = Path.cwd().resolve()
 
             # Look for manage.py in current directory and parents
             for path in [current_path] + list(current_path.parents):
@@ -499,9 +500,9 @@ class DjangoConfig(BaseModel):
                     self._base_dir = path
                     break
 
-            # If still not found, use current directory
+            # If still not found, use current working directory
             if self._base_dir is None:
-                self._base_dir = Path.cwd()
+                self._base_dir = current_path
 
         return self._base_dir
 
