@@ -72,7 +72,13 @@ class SecurityBuilder:
                 "localhost",
                 "127.0.0.1",
                 "[::1]",  # IPv6 localhost
+                ".localhost",  # Allow subdomains of localhost
             ])
+            # Allow all IP addresses in development (for Docker internal IPs, health checks, etc.)
+            # Regex pattern matches any IPv4 address
+            allowed_hosts.append(r"^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$")
+            # Allow common Docker service names
+            allowed_hosts.extend(["django", "postgres", "redis", "frontend-cloud", "frontend-3d"])
 
         # Add security domains (both dev and prod)
         allowed_hosts.extend(self.config.security_domains)
