@@ -5,23 +5,22 @@ Provides automatic URL registration for django_cfg endpoints and integrations.
 """
 
 from typing import List
-from django.urls import path, include, URLPattern
-from django_cfg.core.environment import EnvironmentDetector
+
 from django.conf import settings
+from django.urls import URLPattern, include, path
 
 
-def add_django_cfg_urls(urlpatterns: List[URLPattern], cfg_prefix: str = "cfg/") -> List[URLPattern]:
+def add_django_cfg_urls(urlpatterns: List[URLPattern]) -> List[URLPattern]:
     """
     Automatically add django_cfg URLs and all integrations to the main URL configuration.
     
     This function adds:
-    - Django CFG management URLs (cfg/)
-    - Django Revolution URLs (if available)
+    - Django CFG management URLs
+    - Django Client URLs (if available)
     - Startup information display (based on config)
     
     Args:
         urlpatterns: Existing URL patterns list
-        cfg_prefix: URL prefix for django_cfg endpoints (default: "cfg/")
         
     Returns:
         Updated URL patterns list with all URLs added
@@ -35,24 +34,14 @@ def add_django_cfg_urls(urlpatterns: List[URLPattern], cfg_prefix: str = "cfg/")
             path("admin/", admin.site.urls),
         ]
         
-        # Automatically adds:
-        # - path("cfg/", include("django_cfg.apps.urls"))
-        # - Django Revolution URLs (if available)
-        # - Startup info display (based on config.startup_info_mode)
+        # Automatically adds django_cfg URLs with proper prefixes
         urlpatterns = add_django_cfg_urls(urlpatterns)
     """
     # Add django_cfg API URLs
+    # Note: URL prefixes (cfg/, health/, etc.) are defined in django_cfg.apps.urls
     new_patterns = urlpatterns + [
-        path(cfg_prefix, include("django_cfg.apps.urls")),
+        path("", include("django_cfg.apps.urls")),
     ]
-    
-    # Try to add Django Revolution URLs if available
-    try:
-        from django_revolution import add_revolution_urls
-        new_patterns = add_revolution_urls(new_patterns)
-    except ImportError:
-        # Django Revolution not available - skip
-        pass
 
     # Add django-browser-reload URLs in development (if installed)
     if settings.DEBUG:
@@ -83,20 +72,20 @@ def get_django_cfg_urls_info() -> dict:
         Dictionary with complete URL integration info
     """
     from django_cfg.config import (
-        LIB_NAME,
-        LIB_SITE_URL,
         LIB_DOCS_URL,
         LIB_GITHUB_URL,
-        LIB_SUPPORT_URL,
         LIB_HEALTH_URL,
+        LIB_NAME,
+        LIB_SITE_URL,
+        LIB_SUPPORT_URL,
     )
-    
+
     try:
         from django_cfg import __version__
         version = __version__
     except ImportError:
         version = "unknown"
-    
+
     # Get current config directly from Pydantic
     config = None
     try:
@@ -104,8 +93,8 @@ def get_django_cfg_urls_info() -> dict:
         config = get_current_config()
     except Exception:
         pass
-    
-    
+
+
     info = {
         "django_cfg": {
             "version": version,
@@ -121,14 +110,19 @@ def get_django_cfg_urls_info() -> dict:
             "startup_info_mode": config.startup_info_mode if config else "full",
         }
     }
-    
-    # Add Django Revolution info if available
+
+    # Add Django Client info if available
     try:
-        from django_revolution import get_revolution_urls_info
-        revolution_info = get_revolution_urls_info()
-        if revolution_info:
-            info["django_revolution"] = revolution_info
+        from django_cfg.modules.django_client.core.config.service import DjangoOpenAPI
+        service = DjangoOpenAPI.instance()
+        if service.config and service.config.enabled:
+            info["django_client"] = {
+                "enabled": True,
+                "groups": len(service.config.groups),
+                "base_url": service.config.base_url,
+                "output_dir": service.config.output_dir,
+            }
     except ImportError:
         pass
-    
+
     return info
