@@ -2,15 +2,15 @@
 Pydantic 2 models for configuration.
 """
 
-from .base import BaseConfig
-from .display_models import UserDisplayConfig, MoneyDisplayConfig, DateTimeDisplayConfig
+from .action_models import ActionConfig, ActionVariant
 from .badge_models import BadgeConfig, BadgeVariant, StatusBadgeConfig
-from .action_models import ActionVariant, ActionConfig
+from .base import BaseConfig
+from .display_models import DateTimeDisplayConfig, MoneyDisplayConfig, UserDisplayConfig
 
 __all__ = [
     "BaseConfig",
     "UserDisplayConfig",
-    "MoneyDisplayConfig", 
+    "MoneyDisplayConfig",
     "DateTimeDisplayConfig",
     "BadgeConfig",
     "BadgeVariant",
